"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const mongodb_connection_string_url_1 = __importDefault(require("mongodb-connection-string-url"));
function buildConnectionString(username, password, authenticationDatabase, authenticationMechanism) {
    const uri = new mongodb_connection_string_url_1.default('mongodb://localhost:28006/db1');
    uri.username = username;
    uri.password = password;
    uri.searchParams.set('authSource', authenticationDatabase);
    if (authenticationMechanism) {
        uri.searchParams.set('authMechanism', authenticationMechanism);
    }
    return uri.href;
}
exports.default = {
    dockerCompose: {
        projectName: path_1.default.basename(__dirname),
        yamlPath: path_1.default.resolve(__dirname, 'docker-compose.yaml'),
    },
    waitOn: ['tcp:28006'],
    connections: {
        scramReadWriteAnyDatabase: {
            connectionString: buildConnectionString('user1', 'password', 'admin'),
        },
        scramReadWriteAnyDatabaseScramSha1: {
            connectionString: buildConnectionString('user1', 'password', 'admin', 'SCRAM-SHA-1'),
        },
        scramReadWriteAnyDatabaseScramSha256: {
            connectionString: buildConnectionString('user1', 'password', 'admin', 'SCRAM-SHA-256'),
        },
        scramOnlyScramSha1: {
            connectionString: buildConnectionString('scramSha1', 'password', 'admin', 'SCRAM-SHA-1'),
        },
        scramOnlyScramSha256: {
            connectionString: buildConnectionString('scramSha256', 'password', 'admin', 'SCRAM-SHA-256'),
        },
        scramEncodedPassword: {
            connectionString: buildConnectionString('randomPassword', encodeURIComponent('C;Ib86n5b8{AnExew[TU%XZy,)E6G!dk'), 'admin'),
        },
        scramPrivilegesOnNonExistingDatabases: {
            connectionString: buildConnectionString('user2', 'password', 'admin'),
        },
        scramPrivilegesOnNonExistingCollections: {
            connectionString: buildConnectionString('customRole', 'password', 'admin'),
        },
        scramAlternateAuthDb: {
            connectionString: buildConnectionString('authDb', 'password', 'authDb'),
        },
    },
};
