"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const uuid_1 = require("uuid");
const execa_1 = __importDefault(require("execa"));
const wait_on_1 = __importDefault(require("wait-on"));
const hostile_1 = __importDefault(require("hostile"));
const util_1 = __importDefault(require("util"));
const path_1 = __importDefault(require("path"));
const setHostEntry = util_1.default.promisify(hostile_1.default.set.bind(hostile_1.default));
const removeHostEntry = util_1.default.promisify(hostile_1.default.remove.bind(hostile_1.default));
class TestEnvironment {
    constructor(config) {
        this.config = config;
        const dockerComposeYaml = config.dockerCompose.yamlPath;
        const dockerComposeProjectName = `${config.dockerCompose.projectName}-${uuid_1.v4()}`;
        this._dockerComposeArgs = [
            '-p',
            dockerComposeProjectName,
            '-f',
            path_1.default.basename(dockerComposeYaml),
        ];
        this._dockerComposeCwd = path_1.default.dirname(dockerComposeYaml);
    }
    async start() {
        const args = [
            ...this._dockerComposeArgs,
            'up',
            '-d',
            '--force-recreate',
            '--remove-orphans',
        ];
        for (const host of this.config.hosts || []) {
            await setHostEntry('127.0.0.1', host);
        }
        await execa_1.default('docker-compose', args, {
            cwd: this._dockerComposeCwd,
            stdio: 'inherit',
        });
        await wait_on_1.default({
            resources: this.config.waitOn || [],
            timeout: 5 * 60000,
        });
        if (this.config.setup) {
            await this.config.setup();
        }
    }
    async stop() {
        try {
            for (const host of this.config.hosts || []) {
                await removeHostEntry('127.0.0.1', host);
            }
        }
        catch (error) {
            console.error('failed to remove host entries, skipping. Caused by:', error);
        }
        try {
            await (this.config.teardown || (() => Promise.resolve()))();
        }
        catch (error) {
            console.error('failed config teardown, skipping. Caused by:', error);
        }
        await execa_1.default('docker-compose', [...this._dockerComposeArgs, 'down', '-v', '--remove-orphans'], { cwd: this._dockerComposeCwd });
    }
}
exports.default = TestEnvironment;
