"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class TestEnvironments {
    constructor(environments) {
        this._envs = environments;
        this._connections = {};
        for (const env of Object.values(environments)) {
            this._connections = {
                ...this._connections,
                ...env.config.connections,
            };
        }
    }
    getConnectionOptions(id) {
        const connectionOptions = this._connections[id];
        if (!connectionOptions) {
            throw new Error(`Missing connection options with id ${id}`);
        }
        return connectionOptions;
    }
    async setup() {
        await Promise.all(Object.values(this._envs).map((env) => env.start()));
    }
    async teardown() {
        await Promise.all(Object.values(this._envs).map((env) => env.stop()));
    }
}
exports.default = TestEnvironments;
